@@ -142,7 +142,7 @@ impl MapxRawVs {
         version_name: VersionName,
     ) -> Option<RawValue> {
         let branch_id = self.inner.get_branch_id(branch_name)?;
-        let version_id = self.inner.get_version_id(branch_name, version_name)?;
+        let version_id = self.inner.get_version_id(version_name)?;
         self.inner.get_by_branch_version(key, branch_id, version_id)
     }
 
@@ -178,7 +178,7 @@ impl MapxRawVs {
         version_name: VersionName,
     ) -> Option<(RawKey, RawValue)> {
         let branch_id = self.inner.get_branch_id(branch_name)?;
-        let version_id = self.inner.get_version_id(branch_name, version_name)?;
+        let version_id = self.inner.get_version_id(version_name)?;
         self.inner
             .get_ge_by_branch_version(key, branch_id, version_id)
     }
@@ -215,7 +215,7 @@ impl MapxRawVs {
         version_name: VersionName,
     ) -> Option<(RawKey, RawValue)> {
         let branch_id = self.inner.get_branch_id(branch_name)?;
-        let version_id = self.inner.get_version_id(branch_name, version_name)?;
+        let version_id = self.inner.get_version_id(version_name)?;
         self.inner
             .get_le_by_branch_version(key, branch_id, version_id)
     }
@@ -241,10 +241,7 @@ impl MapxRawVs {
         version_name: VersionName,
     ) -> MapxRawVsIter {
         let branch_id = self.inner.get_branch_id(branch_name).unwrap_or(NULL);
-        let version_id = self
-            .inner
-            .get_version_id(branch_name, version_name)
-            .unwrap_or(NULL);
+        let version_id = self.inner.get_version_id(version_name).unwrap_or(NULL);
         self.inner.iter_by_branch_version(branch_id, version_id)
     }
 
@@ -277,10 +274,7 @@ impl MapxRawVs {
         bounds: R,
     ) -> MapxRawVsIter<'a> {
         let branch_id = self.inner.get_branch_id(branch_name).unwrap_or(NULL);
-        let version_id = self
-            .inner
-            .get_version_id(branch_name, version_name)
-            .unwrap_or(NULL);
+        let version_id = self.inner.get_version_id(version_name).unwrap_or(NULL);
         self.inner
             .range_by_branch_version(branch_id, version_id, bounds)
     }
@@ -314,10 +308,7 @@ impl MapxRawVs {
         bounds: R,
     ) -> MapxRawVsIter<'a> {
         let branch_id = self.inner.get_branch_id(branch_name).unwrap_or(NULL);
-        let version_id = self
-            .inner
-            .get_version_id(branch_name, version_name)
-            .unwrap_or(NULL);
+        let version_id = self.inner.get_version_id(version_name).unwrap_or(NULL);
         self.inner
             .range_ref_by_branch_version(branch_id, version_id, bounds)
     }
@@ -372,7 +363,7 @@ impl MapxRawVs {
             .get_branch_id(branch_name)
             .and_then(|br_id| {
                 self.inner
-                    .get_version_id(branch_name, version_name)
+                    .get_version_id(version_name)
                     .map(|ver_id| self.inner.len_by_branch_version(br_id, ver_id))
             })
             .unwrap_or(0)
@@ -438,7 +429,7 @@ impl VsMgmt for MapxRawVs {
     #[inline(always)]
     fn version_exists(&self, version_name: VersionName) -> bool {
         self.inner
-            .get_version_id(INITIAL_BRANCH_NAME, version_name)
+            .get_version_id(version_name)
             .map(|id| self.inner.version_exists(id))
             .unwrap_or(false)
     }
@@ -454,7 +445,7 @@ impl VsMgmt for MapxRawVs {
             .get_branch_id(branch_name)
             .and_then(|br_id| {
                 self.inner
-                    .get_version_id(branch_name, version_name)
+                    .get_version_id(version_name)
                     .map(|ver_id| self.inner.version_exists_on_branch(ver_id, br_id).0)
             })
             .unwrap_or(false)
@@ -477,7 +468,7 @@ impl VsMgmt for MapxRawVs {
             .get_branch_id(branch_name)
             .and_then(|br_id| {
                 self.inner
-                    .get_version_id(branch_name, version_name)
+                    .get_version_id(version_name)
                     .map(|ver_id| self.inner.version_created_on_branch(ver_id, br_id))
             })
             .unwrap_or(false)
@@ -547,7 +538,7 @@ impl VsMgmt for MapxRawVs {
             .c(d!("base branch not found"))?;
         let base_ver_id = self
             .inner
-            .get_version_id(BranchName(base_branch_name.0), base_version_name)
+            .get_version_id(base_version_name)
             .c(d!("base vesion not found"))?;
         self.inner
             .branch_create_by_base_branch_version(branch_name.0, base_br_id, base_ver_id)
@@ -624,7 +615,7 @@ impl VsMgmt for MapxRawVs {
             .c(d!("branch not found"))
             .and_then(|br_id| {
                 self.inner
-                    .get_version_id(branch_name, last_version_name)
+                    .get_version_id(last_version_name)
                     .c(d!("version not found"))
                     .and_then(|last_ver_id| {
                         self.inner.branch_truncate_to(br_id, last_ver_id).c(d!())
